@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "poly-org" "0.2.2"
+(define-package "poly-org" "20241208.1024"
   "Polymode for org-mode."
   '((emacs    "25")
     (polymode "0.2.2"))
   :url "https://github.com/polymode/poly-org"
-  :commit "8f4d11489532be98a291258ca27405aa528fc126"
-  :revdesc "8f4d11489532"
+  :commit "90d9ca9f440d3b6c03b185353edd37a100559ec4"
+  :revdesc "90d9ca9f440d"
   :keywords '("languages" "multi-modes"))
